Learn R Programming

spatsurv (version 0.9-11)

Et_PP: Et_PP function

Description

A function to compute an individual's approximate expected survival time using numerical integration. Note this appears to be unstable; the function is based on R's integrate function. Not intended for general use (yet!).

Usage

Et_PP(inputs)

Arguments

inputs
inputs for the function including the model matrix, frailties, fixed effects and the parameters of the baseline hazard derived from this model

Value

  • the expected survival time for the individual, obtained by numerical integration of the density function.