Learn R Programming

spatsurv (version 0.9-11)

GammaFromY_SPDE: GammaFromY_SPDE function

Description

A function to go from Y to Gamma

Usage

GammaFromY_SPDE(Y, U, mu)

Arguments

Y
Y
U
upper Cholesky matrix
mu
the mean

Value

  • the value of Gamma for the given Y

References

  1. Benjamin M. Taylor. Auxiliary Variable Markov Chain Monte Carlo for Spatial Survival and Geostatistical Models. Benjamin M. Taylor. Submitted.http://arxiv.org/abs/1501.01665
  2. Finn Lindgren, Havard Rue, Johan Lindstrom. An explicit link between Gaussian fields and Gaussian Markov random fields: the stochastic partial differential equation approach. Journal of the Royal Statistical Society: Series B 73(4)