Learn R Programming

spatsurv (version 0.9-11)

SPDEprec: SPDEprec function

Description

A function to used in entering elements into the precision matrix of an SPDE model. Not intended for general use.

Usage

SPDEprec(a, ord)

Arguments

a
parameter a, see Lindgren et al 2011.
ord
the order of the SPDE model, see Lindgren et al 2011.

Value

  • a function used for creating the precision matrix

References

  1. Benjamin M. Taylor. Auxiliary Variable Markov Chain Monte Carlo for Spatial Survival and Geostatistical Models. Benjamin M. Taylor. Submitted.http://arxiv.org/abs/1501.01665
  2. Finn Lindgren, Havard Rue, Johan Lindstrom. An explicit link between Gaussian fields and Gaussian Markov random fields: the stochastic partial differential equation approach. Journal of the Royal Statistical Society: Series B 73(4)