Learn R Programming

spatsurv (version 0.9-11)

Summarise: Summarise function

Description

A function to completely summarise the output of an object of class mcmcspatsurv.

Usage

Summarise(obj, digits = 3, scientific = -3, inclIntercept = FALSE,
  printmode = "LaTeX", displaymode = "console", ...)

Arguments

obj
an object produced by a call to lgcpPredictSpatialPlusPars, lgcpPredictAggregateSpatialPlusPars, lgcpPredictSpatioTemporalPlusPars orlgcpPredictMultitypeSpatialPlusPars
digits
see the option "digits" in ?format
scientific
see the option "scientific" in ?format
inclIntercept
logical: whether to summarise the intercept term, default is FALSE.
printmode
the format of the text to return, can be 'LaTeX' (the default) or 'text' for plain text.
displaymode
default is 'console' alternative is 'rstudio'
...
other arguments passed to the function "format"

Value

  • A text summary, that can be pasted into a LaTeX document and later edited.