Usage
baselinehazard(x, t = NULL, n = 100, probs = c(0.025, 0.5, 0.975),
cumulative = FALSE, plot = TRUE, bw = FALSE, ...)
Arguments
x
an object inheriting class mcmcspatsurv
t
optional vector of times at which to compute the quantiles, Defult is NULL, in which case a uniformly spaced vector of length n from 0 to the maximum time is used
n
the number of points at which to compute the quantiles if t is NULL
probs
vector of probabilities
cumulative
logical, whether to return the baseline hazard (default i.e. FALSE) or cumulative baseline hazard
plot
whether to plot the result
bw
Logical. Plot in black/white/greyscale? Default is to produce a colour plot. Useful for producing plots for journals that do not accept colour plots.
...
additional arguments to be passed to plot