Learn R Programming

spatsurv (version 0.9-11)

checkSurvivalData: checkSurvivalData function

Description

A function to check whether the survival data to be passed to survspat is in the correct format

Usage

checkSurvivalData(s)

Arguments

s
an object of class Surv, from the survival package

Value

  • if there are any issues with data format, these are returned with the data an error message explaining any issues with the data