Rdocumentation
powered by
Learn R Programming
spatsurv (version 0.9-11)
density_PP: density_PP function
Description
A function to compute an individual's density function
Usage
density_PP(inputs)
Arguments
inputs
inputs for the function including the model matrix, frailties, fixed effects and the parameters of the baseline hazard derived from this model
Value
the density function for the individual