Learn R Programming

spatsurv (version 0.9-11)

densityquantile_PP: densityquantile_PP function

Description

A function to compute quantiles of the density function

Usage

densityquantile_PP(inputs)

Arguments

inputs
inputs for the function including the model matrix, frailties, fixed effects and the parameters of the baseline hazard derived from this model

Value

  • quantiles of the density function for the individual