Learn R Programming

spatsurv (version 0.9-11)

derivindepGaussianprior: derivindepGaussianprior function

Description

A function for evaluating the first and second derivatives of the log of an independent Gaussian prior

Usage

derivindepGaussianprior(beta = NULL, omega = NULL, eta = NULL, priors)

Arguments

beta
a vector, the parameter beta
omega
a vector, the parameter omega
eta
a vector, the parameter eta
priors
an object of class 'mcmcPrior', see ?mcmcPrior

Value

  • returns the first and second derivatives of the prior

See Also

survspat, betapriorGauss, omegapriorGauss, etapriorGauss, indepGaussianprior, derivindepGaussianprior