Learn R Programming

spatsurv (version 0.9-11)

distinfo: distinfo function

Description

Generic function for returning information about the class of baseline hazard functions employed.

Usage

distinfo(obj, ...)

Arguments

obj
an object
...
additional argument -- currently there are none, but this is for extensibility

Value

  • method distinfo

See Also

distinfo.basehazardspec, exponentialHaz, weibullHaz, gompertzHaz, makehamHaz, tpowHaz