Learn R Programming

spatsurv (version 0.9-11)

distinfo.basehazardspec: distinfo.basehazardspec function

Description

A function to retrive information on the baseline hazard distribution of choice

Usage

## S3 method for class 'basehazardspec':
distinfo(obj, ...)

Arguments

obj
an object of class basehazardspec
...
additional arguments -- currently there are none, but this is for extensibility

Value

  • a function returning information on the baseline hazard distribution of choice

See Also

exponentialHaz, weibullHaz, gompertzHaz, makehamHaz, tpowHaz