Learn R Programming

spatsurv (version 0.9-11)

frailtylag1: frailtylag1 function

Description

A function to produce a plot of, and return, the lag 1 (or higher, see argument 'lag') autocorrelation for each of the spatially correlated frailty chains

Usage

frailtylag1(object, plot = TRUE, lag = 1, ...)

Arguments

object
an object inheriting class mcmcspatsurv
plot
logical whether to plot the result, default is TRUE
lag
the lag to plot, the default is 1
...
other arguments to be passed to the plot function

Value

  • the lag 1 autocorrelation for each of the spatially correlated frailty chains

See Also

print.mcmcspatsurv, quantile.mcmcspatsurv, summary.mcmcspatsurv, vcov.mcmcspatsurv, spatialpars, hazardpars, fixedpars, randompars, baselinehazard, predict.mcmcspatsurv, priorposterior, posteriorcov, MCE, hazardexceedance