Learn R Programming

spatsurv (version 0.9-11)

getcov: getcov function

Description

A function to return the covariance from a model based on the randomFields covariance functions. Not intended for general use.

Usage

getcov(u, sigma, phi, model, pars)

Arguments

u
distance
sigma
variance parameter
phi
scale parameter
model
correlation type, see ?CovarianceFct
pars
vector of additional parameters for certain classes of covariance function (eg Matern), these must be supplied in the order given in ?CovarianceFct and are not estimated

Value

  • this is just a wrapper for CovarianceFct