Learn R Programming

spatsurv (version 0.9-11)

gradbasehazard: gradbasehazard function

Description

Generic function for computing the gradient of the baseline hazard

Usage

gradbasehazard(obj, ...)

Arguments

obj
an object
...
additional arguments -- currently there are none, but this is for extensibility

Value

  • method gradbasehazard

See Also

gradbasehazard.basehazardspec, exponentialHaz, weibullHaz, gompertzHaz, makehamHaz, tpowHaz