Learn R Programming

spatsurv (version 0.9-11)

gradcumbasehazard: gradcumbasehazard function

Description

Generic function for computing the gradient of the cumulative baseline hazard

Usage

gradcumbasehazard(obj, ...)

Arguments

obj
an object
...
additional arguments -- currently there are none, but this is for extensibility

Value

  • method gradcumbasehazard

See Also

gradcumbasehazard.basehazardspec, exponentialHaz, weibullHaz, gompertzHaz, makehamHaz, tpowHaz