Learn R Programming

spatsurv (version 0.9-11)

gradcumbasehazard.basehazardspec: gradcumbasehazard.basehazardspec function

Description

A function to retrieve the gradient of the cumulative baseline hazard function

Usage

## S3 method for class 'basehazardspec':
gradcumbasehazard(obj, ...)

Arguments

obj
an object of class basehazardspec
...
additional arguments -- currently there are none, but this is for extensibility

Value

  • a function returning the gradient of the cumulative baseline hazard

See Also

exponentialHaz, weibullHaz, gompertzHaz, makehamHaz, tpowHaz