Learn R Programming

spatsurv (version 0.9-11)

hazard_PP: hazard_PP function

Description

A function to compute an individual's hazard function.

Usage

hazard_PP(inputs)

Arguments

inputs
inputs for the function including the model matrix, frailties, fixed effects and the parameters of the baseline hazard derived from this model

Value

  • the hazard function for the individual