Rdocumentation
powered by
Learn R Programming
spatsurv (version 0.9-11)
hazardexceedance: hazardexceedance function
Description
A function to compute exceedance probabilities for the spatially correlated frailties.
Usage
hazardexceedance(threshold, direction = "upper")
Arguments
threshold
vector of thresholds
direction
default is "upper" which will calculate P(Y>threshold), alternative is "lower", which will calculate P(Y
Value
a function that can be passed to the function MCE in order to compute the exceedance probabilities
See Also
print.mcmcspatsurv
,
quantile.mcmcspatsurv
,
summary.mcmcspatsurv
,
vcov.mcmcspatsurv
,
frailtylag1
,
spatialpars
,
hazardpars
,
fixedpars
,
randompars
,
baselinehazard
,
predict.mcmcspatsurv
,
priorposterior
,
posteriorcov
,
MCE
,