Learn R Programming

spatsurv (version 0.9-11)

hessbasehazard: hessbasehazard function

Description

Generic function for computing the hessian of the baseline hazard

Usage

hessbasehazard(obj, ...)

Arguments

obj
an object
...
additional arguments -- currently there are none, but this is for extensibility

Value

  • method hessbasehazard

See Also

hessbasehazard.basehazardspec, exponentialHaz, weibullHaz, gompertzHaz, makehamHaz, tpowHaz