Rdocumentation
powered by
Learn R Programming
spatsurv (version 0.9-11)
hessbasehazard.basehazardspec: hessbasehazard.basehazardspec function
Description
A function to retrieve the Hessian of the baseline hazard function
Usage
## S3 method for class 'basehazardspec': hessbasehazard(obj, ...)
Arguments
obj
an object of class basehazardspec
...
additional arguments -- currently there are none, but this is for extensibility
Value
a function returning the Hessian of the baseline hazard
See Also
exponentialHaz
,
weibullHaz
,
gompertzHaz
,
makehamHaz
,
tpowHaz