Learn R Programming

spatsurv (version 0.9-11)

hesscumbasehazard: hesscumbasehazard function

Description

Generic function for computing the Hessian of the cumulative baseline hazard

Usage

hesscumbasehazard(obj, ...)

Arguments

obj
an object
...
additional arguments -- currently there are none, but this is for extensibility

Value

  • method hesscumbasehazard

See Also

hesscumbasehazard.basehazardspec, exponentialHaz, weibullHaz, gompertzHaz, makehamHaz, tpowHaz