Learn R Programming

spatsurv (version 0.9-11)

indepGaussianprior: indepGaussianprior function

Description

A function for evaluating the log of an independent Gaussian prior for a given set of parameter values.

Usage

indepGaussianprior(beta = NULL, omega = NULL, eta = NULL, priors)

Arguments

beta
parameter beta at which prior is to be evaluated
omega
parameter omega at which prior is to be evaluated
eta
parameter eta at which prior is to be evaluated
priors
an object of class mcmcPriors, see ?mcmcPriors

Value

  • the log of the prior evaluated at the given parameter values

See Also

survspat, betapriorGauss, omegapriorGauss, etapriorGauss, indepGaussianprior, derivindepGaussianprior