Learn R Programming

spatsurv (version 0.9-11)

inference.control: inference.control function

Description

A function to control inferential settings. This function is used to set parameters for more advanced use of spatsurv.

Usage

inference.control(gridded = FALSE, cellwidth = NULL, ext = 2,
  optimcontrol = NULL, hessian = FALSE, plotcal = FALSE,
  timeonlyMCMC = FALSE)

Arguments

gridded
logical. Whether to perform compuation on a grid. Default is FALSE.
cellwidth
the width of computational cells to use
ext
integer the number of times to extend the computational grid by in order to perform compuitation. The default is 2.
optimcontrol
a list of optional arguments to be passed to optim for non-spatial models
hessian
whether to return a numerical hessian. Set this to TRUE for non-spatial models. equal to the number of parameters of the baseline hazard
plotcal
logical, whether to produce plots of the MCMC calibration process, this is a technical option and should onyl be set to TRUE if poor mixing is evident (the printed h is low), then it is also useful to use a graphics device with multiple plotting windows.
timeonlyMCMC
logical, whether to only time the MCMC part of the algorithm, or whether to include in the reported running time the time taken to calibrate the method (default)

Value

  • returns parameters to be used in the function survspat

See Also

survspat