Learn R Programming

spatsurv (version 0.9-11)

logPosterior: logPosterior function

Description

A function to evaluate the log-posterior of a spatial parametric proportional hazards model. Not intended for general use.

Usage

logPosterior(surv, X, beta, omega, eta, gamma, priors, cov.model, u, control,
  gradient = FALSE, hessian = FALSE)

Arguments

surv
an object of class Surv
X
the design matrix, containing covariate information
beta
parameter beta
omega
parameter omega
eta
parameter eta
gamma
parameter gamma
priors
the priors, an object of class 'mcmcPriors'
cov.model
the spatial covariance model
u
vector of interpoint distances
control
a list containg various control parameters for the MCMC and post-processing routines
gradient
logical whether to evaluate the gradient
hessian
logical whether to evaluate the Hessian

Value

  • evaluates the log-posterior and the gradient and hessian, if required.

References

  1. Benjamin M. Taylor. Auxiliary Variable Markov Chain Monte Carlo for Spatial Survival and Geostatistical Models. Benjamin M. Taylor. Submitted.http://arxiv.org/abs/1501.01665