A function to get initial estimates of model parameters using maximum likelihood. Not intended for general purose use.
Usage
maxlikparamPHsurv(surv, X, control)
Arguments
surv
an object of class Surv
X
the design matrix, containing covariate information
control
a list containg various control parameters for the MCMC and post-processing routines
Value
initial estimates of the parameters
References
Benjamin M. Taylor. Auxiliary Variable Markov Chain Monte Carlo for Spatial Survival and Geostatistical Models. Benjamin M. Taylor. Submitted.http://arxiv.org/abs/1501.01665