mcmcPriors(betaprior = NULL, omegaprior = NULL, etaprior = NULL,
call = NULL, derivative = NULL)spatsurv only provides functionality for the built-in Gaussian priors. However, the choice of prior is
extensible by the user by creating functions similar to the functions betapriorGauss, omegapriorGauss, etapriorGauss,
indepGaussianprior and derivindepGaussianprior: the first three of which provide a mechanism for storing and retrieving the
parameters of the priors; the fourth, a function for evaluating the log of the prior for a given set of parameter values; and the fifth, a
function for evaluating the first and second derivatives of the log of the prior. It is assumed that parameters are a priori independent.
The user interested in using other priors is encouraged to look at the structure of the five functions mentioned above.