Learn R Programming

spatsurv (version 0.9-11)

neighOrder: neighOrder function

Description

A function to compute the order of a set of neighbours. Not intended for general use.

Usage

neighOrder(neighlocs)

Arguments

neighlocs
an object created by the function neighLocs

Value

  • the neighbour orders

References

  1. Benjamin M. Taylor. Auxiliary Variable Markov Chain Monte Carlo for Spatial Survival and Geostatistical Models. Benjamin M. Taylor. Submitted.http://arxiv.org/abs/1501.01665
  2. Finn Lindgren, Havard Rue, Johan Lindstrom. An explicit link between Gaussian fields and Gaussian Markov random fields: the stochastic partial differential equation approach. Journal of the Royal Statistical Society: Series B 73(4)