Learn R Programming

spatsurv (version 0.9-11)

omegapriorGauss: omegapriorGauss function

Description

A function to define Gaussian priors for omega. This function simply stores a vector of means and standard deviations to be passed to the main MCMC function, survspat.

Usage

omegapriorGauss(mean, sd)

Arguments

mean
the prior mean, a vector of length 1 or more. 1 implies a common mean.
sd
the prior standard deviation, a vector of length 1 or more. 1 implies a common standard deviation.

Value

  • an object of class "omegapriorGauss"

See Also

survspat, betapriorGauss, omegapriorGauss, etapriorGauss, indepGaussianprior, derivindepGaussianprior