Learn R Programming

spatsurv (version 0.9-11)

posteriorcov: posteriorcov function

Description

A function to produce a plot of the posterior covariance function with upper and lower quantiles.

Usage

posteriorcov(x, probs = c(0.025, 0.5, 0.975), rmax = NULL, n = 100,
  plot = TRUE, bw = FALSE, ...)

Arguments

x
an object of class mcmcspatsurv
probs
vector of probabilities to be fed to quantile function
rmax
maximum distance in space to compute this distance up to
n
the number of points at which to evaluate the posterior covariance.
plot
whether to plot the result
bw
Logical. Plot in black/white/greyscale? Default is to produce a colour plot. Useful for producing plots for journals that do not accept colour plots.
...
other arguments to be passed to matplot function

Value

  • produces a plot of the posterior spatial covariance function.

See Also

print.mcmcspatsurv, quantile.mcmcspatsurv, summary.mcmcspatsurv, vcov.mcmcspatsurv, frailtylag1, spatialpars, hazardpars, fixedpars, randompars, baselinehazard, predict.mcmcspatsurv, priorposterior, MCE, hazardexceedance