Learn R Programming

spatsurv (version 0.9-11)

priorposterior: priorposterior function

Description

A function to produce plots of the prior (which shows as a red line) and posterior (showing as a histogram)

Usage

priorposterior(x, breaks = 30, ylab = "Density", main = "",
  pause = TRUE, bw = FALSE, ...)

Arguments

x
an object inheriting class mcmcspatsurv
breaks
see ?hist
ylab
optional y label
main
optional title
pause
logical whether to pause between plots, the default is TRUE
bw
Logical. Plot in black/white/greyscale? Default is to produce a colour plot. Useful for producing plots for journals that do not accept colour plots.
...
other arguments passed to the hist function

Value

  • plots of the prior (red line) and posterior (histogram).

See Also

print.mcmcspatsurv, quantile.mcmcspatsurv, summary.mcmcspatsurv, vcov.mcmcspatsurv, frailtylag1, spatialpars, hazardpars, fixedpars, randompars, baselinehazard, predict.mcmcspatsurv, posteriorcov, MCE, hazardexceedance