Learn R Programming

spatsurv (version 0.9-11)

quantile.mlspatsurv: quantile.mlspatsurv function

Description

A function to extract quantiles of the parameters from an mcmc run

Usage

## S3 method for class 'mlspatsurv':
quantile(x, probs = c(0.025, 0.5, 0.975), ...)

Arguments

x
an object inheriting class mcmcspatsurv
probs
vector of probabilities
...
other arguments to be passed to the function, not used here

Value

  • quantiles of model parameters

See Also

print.mcmcspatsurv, summary.mcmcspatsurv, vcov.mcmcspatsurv, frailtylag1, spatialpars, hazardpars, fixedpars, randompars, baselinehazard, predict.mcmcspatsurv, priorposterior, posteriorcov, MCE, hazardexceedance