Learn R Programming

spatsurv (version 0.9-11)

survspat: survspat function

Description

A function to run a Bayesian analysis on censored spatial survial data assuming a proportional hazards model using an adaptive Metropolis-adjusted Langevin algorithm.

Usage

survspat(formula, data, dist, cov.model, mcmc.control, priors, shape = NULL,
  ids = list(shpid = NULL, dataid = NULL),
  control = inference.control(gridded = FALSE))

Arguments

formula
the model formula in a format compatible with the function flexsurvreg from the flexsurv package
data
a SpatialPointsDataFrame object containing the survival data as one of the columns
dist
choice of distribution function for baseline hazard. Current options are: exponentialHaz, weibullHaz, gompertzHaz, makehamHaz, tpowHaz
cov.model
an object of class covmodel, see ?covmodel ?ExponentialCovFct or ?SpikedExponentialCovFct
mcmc.control
mcmc control parameters, see ?mcmcpars
priors
an object of class Priors, see ?mcmcPriors
shape
when data is a data.frame, this can be a SpatialPolygonsDataFrame, or a SpatialPointsDataFrame, used to model spatial variation at the small region level. The regions are the polygons, or they represent the (possibly weighted) centroids of the polygons.
ids
named list entry shpid character string giving name of variable in shape to be matched to variable dataid in data. dataid is the second entry of the named list.
control
additional control parameters, see ?inference.control

Value

  • an object inheriting class 'mcmcspatsurv' for which there exist methods for printing, summarising and making inference from.

References

  1. Benjamin M. Taylor. Auxiliary Variable Markov Chain Monte Carlo for Spatial Survival and Geostatistical Models. Benjamin M. Taylor. Submitted.http://arxiv.org/abs/1501.01665

See Also

tpowHaz, exponentialHaz, gompertzHaz, makehamHaz, weibullHaz, covmodel, link{ExponentialCovFct}, SpikedExponentialCovFct, mcmcpars, mcmcPriors, inference.control