Learn R Programming

spatsurv (version 0.9-11)

survspatNS: survspatNS function

Description

A function to perform maximun likelihood inference for non-spatial survival data.

Usage

survspatNS(formula, data, dist, control = inference.control())

Arguments

formula
the model formula in a format compatible with the function flexsurvreg from the flexsurv package
data
a SpatialPointsDataFrame object containing the survival data as one of the columns
dist
choice of distribution function for baseline hazard. Current options are: exponentialHaz, weibullHaz, gompertzHaz, makehamHaz, tpowHaz
control
additional control parameters, see ?inference.control

Value

  • an object inheriting class 'mcmcspatsurv' for which there exist methods for printing, summarising and making inference from.

References

  1. Benjamin M. Taylor. Auxiliary Variable Markov Chain Monte Carlo for Spatial Survival and Geostatistical Models. Benjamin M. Taylor. Submitted.http://arxiv.org/abs/1501.01665

See Also

tpowHaz, exponentialHaz, gompertzHaz, makehamHaz, weibullHaz, covmodel, link{ExponentialCovFct}, SpikedExponentialCovFct, mcmcpars, mcmcPriors, inference.control