GammaFromY_SPDE: GammaFromY_SPDE function
Description
A function to go from Y to GammaUsage
GammaFromY_SPDE(Y, U, mu)
Value
- the value of Gamma for the given Y
References
- Benjamin M. Taylor. Auxiliary Variable Markov Chain Monte Carlo for Spatial Survival and Geostatistical Models. Benjamin M. Taylor. Submitted.http://arxiv.org/abs/1501.01665
- Finn Lindgren, Havard Rue, Johan Lindstrom. An explicit link between Gaussian fields and Gaussian Markov random fields: the stochastic partial differential equation approach. Journal of the Royal Statistical Society: Series B 73(4)