YFromGamma_SPDE: YFromGamma_SPDE function
Description
A function to go from Gamma to YUsage
YFromGamma_SPDE(gamma, U, mu)
Value
- the value of Y for the given Gamma
References
- Benjamin M. Taylor. Auxiliary Variable Markov Chain Monte Carlo for Spatial Survival and Geostatistical Models. Benjamin M. Taylor. Submitted.http://arxiv.org/abs/1501.01665
- Finn Lindgren, Havard Rue, Johan Lindstrom. An explicit link between Gaussian fields and Gaussian Markov random fields: the stochastic partial differential equation approach. Journal of the Royal Statistical Society: Series B 73(4)