Rdocumentation
powered by
Learn R Programming
spatsurv (version 0.9-11)
densityquantile.basehazardspec: densityquantile.basehazardspec function
Description
A function to retrieve the quantiles of the density function
Usage
## S3 method for class 'basehazardspec': densityquantile(obj, ...)
Arguments
obj
an object of class basehazardspec
...
additional arguments -- currently there are none, but this is for extensibility
Value
a function returning the density quantiles
See Also
exponentialHaz
,
weibullHaz
,
gompertzHaz
,
makehamHaz
,
tpowHaz