estimateY: estimateY function
Description
A function to get an initial estimate of Y, to be used in calibrating the MCMC. Not for general useUsage
estimateY(X, betahat, omegahat, surv, control)
Arguments
X
the design matrix containing covariate information
betahat
an estimate of beta
omegahat
an estimate of omega
surv
an object of class Surv
control
a list containg various control parameters for the MCMC and post-processing routines
Value
- an estimate of Y, to be used in calibrating the MCMC