A function to produce a plot of, and return, the lag 1 (or higher, see argument 'lag') autocorrelation for each of the spatially correlated frailty chains
Usage
frailtylag1(object, plot = TRUE, lag = 1, ...)
Arguments
object
an object inheriting class mcmcspatsurv
plot
logical whether to plot the result, default is TRUE
lag
the lag to plot, the default is 1
...
other arguments to be passed to the plot function
Value
the lag 1 autocorrelation for each of the spatially correlated frailty chains