Rdocumentation
powered by
Learn R Programming
spatsurv (version 0.9-11)
getBbasis: getBbasis function
Description
A function returning the piecewise polynomial coefficients for a B-spline basis function i.e. the basis functions.
Usage
getBbasis(x, knots, degree)
Arguments
x
a vector of data
knots
a vector of knots in ascending order. The first and last knots must be respectively the minimum and maximum of x.
degree
the degree of the spline
Value
the knots and the piecewise polynomial coefficients for a B-spline basis function i.e. the basis functions.