Rdocumentation
powered by
Learn R Programming
spatsurv (version 0.9-11)
guess_t: guess_t function
Description
A function to get an initial guess of the failure time t, to be used in calibrating the MCMC. Not for general use
Usage
guess_t(surv)
Arguments
surv
an object of class Surv
Value
a guess at the failure times