A function to get initial estimates of model parameters using maximum likelihood. Not intended for general purose use.
maxlikparamPHsurv(surv, X, control)an object of class Surv
the design matrix, containing covariate information
a list containg various control parameters for the MCMC and post-processing routines
initial estimates of the parameters
Benjamin M. Taylor and Barry S. Rowlingson (2017). spatsurv: An R Package for Bayesian Inference with Spatial Survival Models. Journal of Statistical Software, 77(4), 1-32, doi:10.18637/jss.v077.i04.