A function used in the computation of neighbours on non-rectangular grids. Not intended for general use.
Usage
neighLocs(coord, cellwidth, order)
Arguments
coord
coordinate of interest
cellwidth
a scalar, the width of the grid cells
order
the order of the SPDE approximation: see Lindgren et al 2011 for details
Value
coordinates of centroids of neighbours
References
Benjamin M. Taylor. Auxiliary Variable Markov Chain Monte Carlo for Spatial Survival and Geostatistical Models. Benjamin M. Taylor. Submitted.http://arxiv.org/abs/1501.01665
Finn Lindgren, Havard Rue, Johan Lindstrom. An explicit link between Gaussian fields and Gaussian Markov random fields: the stochastic partial differential equation approach. Journal of the Royal Statistical Society: Series B 73(4)