Rdocumentation
powered by
Learn R Programming
spatsurv (version 0.9-11)
showGrid: showGrid function
Description
A function to show the grid that will be used for a given cellwidth
Usage
showGrid(dat, cellwidth, ext = 2)
Arguments
dat
any spatial data object whose bounding box can be computed using the function bbox.
cellwidth
an initial suggested cellwidth
ext
the extension parameter for the FFT transform, set to 2 by default
Value
a plot showing the grid and the data. Ideally the data should only just fit inside the grid.