spatsurvsection{Dependencies}{
The package spatsurv depends upon some other important contributions to CRAN in order to operate; their uses here are indicated:
survival, sp, spatstat, raster, iterators, RandomFields, fields, rgl, Matrix, stringr, RColorBrewer, geostatsp, rgeos.
}
section{Citation}{
To cite use of spatsurv, the user may refer to the following work:
spatsurv: an R Package for Bayesian Inference with Spatial Survival Models.
Benjamin M. Taylor and Barry S. Rowlingson.
Submitted to The Journal Of Statistical Software.
}
references{ X }