Rdocumentation
powered by
Learn R Programming
spatsurv (version 0.9-11)
survival_PP: survival_PP function
Description
A function to compute an individual's survival function
Usage
survival_PP(inputs)
Arguments
inputs
inputs for the function including the model matrix, frailties, fixed effects and the parameters of the baseline hazard derived from this model
Value
the survival function for the individual