Usage
survspat(formula, data, dist, cov.model, mcmc.control, priors, shape = NULL,
ids = list(shpid = NULL, dataid = NULL),
control = inference.control(gridded = FALSE))
Arguments
formula
the model formula in a format compatible with the function flexsurvreg from the flexsurv package
data
a SpatialPointsDataFrame object containing the survival data as one of the columns
dist
choice of distribution function for baseline hazard. Current options are: exponentialHaz, weibullHaz, gompertzHaz, makehamHaz, tpowHaz
cov.model
an object of class covmodel, see ?covmodel ?ExponentialCovFct or ?SpikedExponentialCovFct
mcmc.control
mcmc control parameters, see ?mcmcpars
priors
an object of class Priors, see ?mcmcPriors
shape
when data is a data.frame, this can be a SpatialPolygonsDataFrame, or a SpatialPointsDataFrame, used to model spatial variation at the small region level. The regions are the polygons, or they represent the (possibly weighted) centroids of the polygons.
ids
named list entry shpid character string giving name of variable in shape to be matched to variable dataid in data. dataid is the second entry of the named list.
control
additional control parameters, see ?inference.control