Rdocumentation
powered by
Learn R Programming
spatsurv (version 0.9-11)
vcov.mlspatsurv: vcov.mlspatsurv function
Description
A function to return the variance covariance matrix of the parameters beta, omega and eta
Usage
## S3 method for class 'mlspatsurv': vcov(object, ...)
Arguments
object
an object inheriting class mcmcspatsurv
...
other arguments, not used here
Value
the variance covariance matrix of the parameters beta, omega and eta
See Also
print.mcmcspatsurv
,
quantile.mcmcspatsurv
,
summary.mcmcspatsurv
,
frailtylag1
,
spatialpars
,
hazardpars
,
fixedpars
,
randompars
,
baselinehazard
,
predict.mcmcspatsurv
,
priorposterior
,
posteriorcov
,
MCE
,
hazardexceedance